#include "secrets.h"

#if defined(ARDUINO_ARCH_ESP32) || defined(ESP32)
#   include <WiFi.h>
#elif defined(ARDUINO_ARCH_ESP8266) || defined(ESP8266)
#   include <ESP8266WiFi.h>
#else
#   error "Unsupported board, please contact the developer"
#endif

#define STATUS_PIN D5
#define WAKE_PIN D6

static bool wifi_lost = false;
static bool server_is_off = false;

void setup() {
  Serial.begin(9600);

  
  WiFi.mode(WIFI_STA);
  WiFi.disconnect();

  Serial.println("Connecting to a Wi-Fi network");
  
  WiFi.begin(WIFI_SSID, WIFI_PASSWORD);
  while (WiFi.status() == WL_IDLE_STATUS) delay(100);

  Serial.println("Wi-Fi connected");

  pinMode(STATUS_PIN, INPUT);
  pinMode(WAKE_PIN, OUTPUT);
}

void loop() {
  wifi_lost = WiFi.status() == 1 || WiFi.status() == 5 || WiFi.status() == 7;
  server_is_off = digitalRead(STATUS_PIN) != HIGH;

  Serial.println("Checking the status");
  Serial.print("WiFi lost: ");
  Serial.println(wifi_lost? "true" : "false");
  Serial.print("Server is off: ");
  Serial.println(server_is_off? "true" : "false");

  if (wifi_lost && server_is_off) {
    Serial.println("The power seems to be down. Waiting for the power to restore and send turn on signal to the server.");
    // Wait untill Wi-Fi is available (i.e. the power is back)
    while (WiFi.status() != WL_CONNECTED) delay(100);
    digitalWrite(WAKE_PIN, HIGH);
    delay(100);
    digitalWrite(WAKE_PIN, LOW);
    Serial.println("Signal sent");
  } else {
    Serial.println("Everyting's okay, sleeping 5 secs");
  }

  delay(5000);
}